==> texinfo-6.8.90.tar.xz: texinfo-6.8.90/tp/t/results/misc_commands/contents.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'contents'} = {
  'contents' => [
    {
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'first '
            },
            {
              'cmdname' => '@',
              'parent' => {}
            },
            {
              'parent' => {},
              'text' => 'contents '
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'parent' => {},
              'text' => ' line following first content
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'contents',
          'parent' => {},
          'source_info' => {
            'file_name' => '',
            'line_nr' => 2,
            'macro' => ''
          }
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'second '
            },
            {
              'cmdname' => '@',
              'parent' => {}
            },
            {
              'parent' => {},
              'text' => 'contents '
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'parent' => {},
              'text' => ' line following second content
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'contents',
          'parent' => {},
          'source_info' => {
            'file_name' => '',
            'line_nr' => 3,
            'macro' => ''
          }
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'Third content on the following line on his own
'
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'parent' => {},
              'text' => '
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'contents',
          'parent' => {},
          'source_info' => {
            'file_name' => '',
            'line_nr' => 5,
            'macro' => ''
          }
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'Line following contents
'
            },
            {
              'parent' => {},
              'text' => 'shortcontents '
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'parent' => {},
              'text' => ' eol
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'shortcontents',
          'parent' => {},
          'source_info' => {
            'file_name' => '',
            'line_nr' => 7,
            'macro' => ''
          }
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'shortcontents '
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'parent' => {},
              'text' => ' eol
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'shortcontents',
          'parent' => {},
          'source_info' => {
            'file_name' => '',
            'line_nr' => 8,
            'macro' => ''
          }
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'summarycontents '
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'parent' => {},
              'text' => ' line following summarycontents
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'summarycontents',
          'parent' => {},
          'source_info' => {
            'file_name' => '',
            'line_nr' => 9,
            'macro' => ''
          }
        }
      ],
      'parent' => {},
      'type' => 'before_node_section'
    }
  ],
  'type' => 'document_root'
};
$result_trees{'contents'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[0];
$result_trees{'contents'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[1];
$result_trees{'contents'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[1];
$result_trees{'contents'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[1];
$result_trees{'contents'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'contents'}{'contents'}[0];
$result_trees{'contents'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[2];
$result_trees{'contents'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'contents'}{'contents'}[0];
$result_trees{'contents'}{'contents'}[0]{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[3];
$result_trees{'contents'}{'contents'}[0]{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[3];
$result_trees{'contents'}{'contents'}[0]{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[3];
$result_trees{'contents'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'contents'}{'contents'}[0];
$result_trees{'contents'}{'contents'}[0]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[4];
$result_trees{'contents'}{'contents'}[0]{'contents'}[4]{'parent'} = $result_trees{'contents'}{'contents'}[0];
$result_trees{'contents'}{'contents'}[0]{'contents'}[5]{'contents'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[5];
$result_trees{'contents'}{'contents'}[0]{'contents'}[5]{'parent'} = $result_trees{'contents'}{'contents'}[0];
$result_trees{'contents'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[6];
$result_trees{'contents'}{'contents'}[0]{'contents'}[6]{'parent'} = $result_trees{'contents'}{'contents'}[0];
$result_trees{'contents'}{'contents'}[0]{'contents'}[7]{'contents'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[7];
$result_trees{'contents'}{'contents'}[0]{'contents'}[7]{'contents'}[1]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[7];
$result_trees{'contents'}{'contents'}[0]{'contents'}[7]{'parent'} = $result_trees{'contents'}{'contents'}[0];
$result_trees{'contents'}{'contents'}[0]{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[8];
$result_trees{'contents'}{'contents'}[0]{'contents'}[8]{'parent'} = $result_trees{'contents'}{'contents'}[0];
$result_trees{'contents'}{'contents'}[0]{'contents'}[9]{'contents'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[9];
$result_trees{'contents'}{'contents'}[0]{'contents'}[9]{'parent'} = $result_trees{'contents'}{'contents'}[0];
$result_trees{'contents'}{'contents'}[0]{'contents'}[10]{'args'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[10];
$result_trees{'contents'}{'contents'}[0]{'contents'}[10]{'parent'} = $result_trees{'contents'}{'contents'}[0];
$result_trees{'contents'}{'contents'}[0]{'contents'}[11]{'contents'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[11];
$result_trees{'contents'}{'contents'}[0]{'contents'}[11]{'parent'} = $result_trees{'contents'}{'contents'}[0];
$result_trees{'contents'}{'contents'}[0]{'contents'}[12]{'args'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[0]{'contents'}[12];
$result_trees{'contents'}{'contents'}[0]{'contents'}[12]{'parent'} = $result_trees{'contents'}{'contents'}[0];
$result_trees{'contents'}{'contents'}[0]{'parent'} = $result_trees{'contents'};

$result_texis{'contents'} = '
first @@contents @contents line following first content
second @@contents @contents line following second content
Third content on the following line on his own
@contents
Line following contents
shortcontents @shortcontents eol
shortcontents @shortcontents eol
summarycontents @summarycontents line following summarycontents
';


$result_texts{'contents'} = '
first @contents second @contents Third content on the following line on his own
Line following contents
shortcontents shortcontents summarycontents ';

$result_errors{'contents'} = [
  {
    'error_line' => 'warning: @contents should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 2,
    'macro' => '',
    'text' => '@contents should only appear at the beginning of a line',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @contents should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 3,
    'macro' => '',
    'text' => '@contents should only appear at the beginning of a line',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @shortcontents should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 7,
    'macro' => '',
    'text' => '@shortcontents should only appear at the beginning of a line',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @shortcontents should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 8,
    'macro' => '',
    'text' => '@shortcontents should only appear at the beginning of a line',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @summarycontents should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 9,
    'macro' => '',
    'text' => '@summarycontents should only appear at the beginning of a line',
    'type' => 'warning'
  }
];


$result_floats{'contents'} = {};


1;

==> texinfo-7.1.1.tar.xz: texinfo-7.1.1/tp/t/results/misc_commands/contents.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'contents'} = {
  'contents' => [
    {
      'contents' => [
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'text' => 'first '
            },
            {
              'cmdname' => '@'
            },
            {
              'text' => 'contents '
            }
          ],
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'text' => ' line following first content
',
              'type' => 'rawline_arg'
            }
          ],
          'cmdname' => 'contents',
          'source_info' => {
            'file_name' => '',
            'line_nr' => 2,
            'macro' => ''
          }
        },
        {
          'contents' => [
            {
              'text' => 'second '
            },
            {
              'cmdname' => '@'
            },
            {
              'text' => 'contents '
            }
          ],
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'text' => ' line following second content
',
              'type' => 'rawline_arg'
            }
          ],
          'cmdname' => 'contents',
          'source_info' => {
            'file_name' => '',
            'line_nr' => 3,
            'macro' => ''
          }
        },
        {
          'contents' => [
            {
              'text' => 'Third content on the following line on his own
'
            }
          ],
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'text' => '
',
              'type' => 'rawline_arg'
            }
          ],
          'cmdname' => 'contents',
          'source_info' => {
            'file_name' => '',
            'line_nr' => 5,
            'macro' => ''
          }
        },
        {
          'contents' => [
            {
              'text' => 'Line following contents
'
            },
            {
              'text' => 'shortcontents '
            }
          ],
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'text' => ' eol
',
              'type' => 'rawline_arg'
            }
          ],
          'cmdname' => 'shortcontents',
          'source_info' => {
            'file_name' => '',
            'line_nr' => 7,
            'macro' => ''
          }
        },
        {
          'contents' => [
            {
              'text' => 'shortcontents '
            }
          ],
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'text' => ' eol
',
              'type' => 'rawline_arg'
            }
          ],
          'cmdname' => 'shortcontents',
          'source_info' => {
            'file_name' => '',
            'line_nr' => 8,
            'macro' => ''
          }
        },
        {
          'contents' => [
            {
              'text' => 'summarycontents '
            }
          ],
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'text' => ' line following summarycontents
',
              'type' => 'rawline_arg'
            }
          ],
          'cmdname' => 'summarycontents',
          'source_info' => {
            'file_name' => '',
            'line_nr' => 9,
            'macro' => ''
          }
        }
      ],
      'type' => 'before_node_section'
    }
  ],
  'type' => 'document_root'
};

$result_texis{'contents'} = '
first @@contents @contents line following first content
second @@contents @contents line following second content
Third content on the following line on his own
@contents
Line following contents
shortcontents @shortcontents eol
shortcontents @shortcontents eol
summarycontents @summarycontents line following summarycontents
';


$result_texts{'contents'} = '
first @contents second @contents Third content on the following line on his own
Line following contents
shortcontents shortcontents summarycontents ';

$result_errors{'contents'} = [
  {
    'error_line' => 'warning: @contents should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 2,
    'macro' => '',
    'text' => '@contents should only appear at the beginning of a line',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @contents should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 3,
    'macro' => '',
    'text' => '@contents should only appear at the beginning of a line',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @shortcontents should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 7,
    'macro' => '',
    'text' => '@shortcontents should only appear at the beginning of a line',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @shortcontents should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 8,
    'macro' => '',
    'text' => '@shortcontents should only appear at the beginning of a line',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @summarycontents should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 9,
    'macro' => '',
    'text' => '@summarycontents should only appear at the beginning of a line',
    'type' => 'warning'
  }
];


$result_floats{'contents'} = {};


1;
